@@ -38,6 +38,8 @@ def test_db():
 
     db = xt.Neo4jOp()
 
+    db = xt.HiveOp()
+
     db = xt.EsOp()
 
     esSearch = xt.BaseSearcher()
@@ -161,6 +163,6 @@ def test_encrypt_dict():
 
 if __name__ == '__main__':
     pass
-    # test_log_info()
+    test_log_info()
     # test_config()
-    test_raise_exception()
+    # test_raise_exception()
