@@ -314,7 +314,7 @@ class UpdateTable(MysqlOp):
                 append_df = origin_df[origin_df[unique_key].isin(append_id_list)]
                 append_df = append_df.drop_duplicates(unique_key)
                 _update_dict['insert'] = append_df.to_dict('records')
-                self.to_sql_write_data(append_df, table_name)
+                self.execute_many_write_data(append_df, table_name)
                 # self.execute_many_write_data(append_df.astype(str), table_name)
                 print(table_name + '表中添加了{}条新记录。'.format(len(append_df)))
             else:
@@ -322,11 +322,11 @@ class UpdateTable(MysqlOp):
 
             update_id_list = list(set(origin_df[unique_key].tolist()) - set(append_id_list))
             if update_id_list:
-                columns_str = ','.join(origin_df.columns.tolist())
+                columns_str = '`' + '`,`'.join(origin_df.columns.tolist()) + '`'
                 if len(update_id_list) != 1:
                     _where = " from {0} where {1} in {2}".format(table_name, unique_key, tuple(update_id_list))
                 else:
-                    _where = " from {0} where {1}='{2}'""".format(table_name, unique_key, update_id_list[0])
+                    _where = " from {0} where `{1}`='{2}'""".format(table_name, unique_key, update_id_list[0])
                 _sql = "select " + columns_str + _where
                 if isinstance(list_dict, list):
                     old_data = self.get_dict_sql(_sql)
@@ -357,8 +357,8 @@ class UpdateTable(MysqlOp):
                     for data_dict in update_data:
                         _sql_update = "update {0} set ".format(table_name, ) + \
                                       ','.join(
-                                          ['%s=%r' % (k, str(data_dict[k])) for k in data_dict if k != unique_key]) + \
-                                      " where {0}='{1}'".format(unique_key, data_dict[unique_key])
+                                          ['`%s`=%r' % (k, str(data_dict[k])) for k in data_dict if k != unique_key]) + \
+                                      " where `{0}`='{1}'".format(unique_key, data_dict[unique_key])
                         # print(_sql_update)
                         self.operate_sql(_sql_update)
                     print(table_name + '更新了{0}条记录。'.format(len(update_data)))
